#!/usr/local/bin/python3.sh
# -*-mode: python; py-indent-offset: 2; indent-tabs-mode: nil; coding: utf-8-unix -*-
# https://stem.torproject.org/tutorials/examples/exit_used.html
__doc__ = """Determine The Exit You're Using

Lets say you're using Tor and one day you run into something odd. Maybe a
misconfigured relay, or maybe one that's being malicious.
How can you figure out what exit you're using?

"""

import functools
import sys
import os
import logging

from stem import StreamStatus
from stem.control import EventType, Controller
from stem_examples.tor_controller import get_controller

global COUNT, IMAX
COUNT=0
IMAX = 0

def stream_event(controller, event):
    global COUNT, IMAX
    COUNT += 1
    if IMAX and COUNT >= IMAX:
        LOG.info(f"exiting COUNT={COUNT}")
        sys.exit(0)
    if event.status == StreamStatus.SUCCEEDED and event.circ_id:
      circ = controller.get_circuit(event.circ_id)

      exit_fingerprint = circ.path[-1][0]
      exit_relay = controller.get_network_status(exit_fingerprint)

      LOG.info("Exit relay for our connection to %s" % (event.target))
      LOG.info("  address: %s:%i" % (exit_relay.address, exit_relay.or_port))
      LOG.info("  fingerprint: %s" % exit_relay.fingerprint)
      LOG.info("  nickname: %s" % exit_relay.nickname)
      LOG.info("  locale: %s" % controller.get_info("ip-to-country/%s" % exit_relay.address, 'unknown'))
      LOG.info("")


def iMain():
    password = os.environ.get('TOR_CONTROLLER_PASSWORD')

    if os.path.exists('/run/tor/control'):
      controller = get_controller(password=password, unix='/run/tor/control')
    else:
      controller = get_controller(password=password, port=9051)

    if IMAX > 0:
        LOG.info("Please wait for requests for tor exits. Press 'enter' to end.")
        print("")
    stream_listener = functools.partial(stream_event, controller)
    controller.add_event_listener(stream_listener, EventType.STREAM)
    input()

if __name__ == '__main__':
    from stem_examples.stem_utils import vsetup_logging
    LOG = logging.getLogger()
    if len(sys.argv) > 1:
        IMAX = int(sys.argv[1])
    else:
        IMAX = 0
    if os.environ.get('DEBUG', ''):
        log_level = 10
    else:
        log_level = 20
    vsetup_logging(LOG, log_level)
    try:
        iMain()
        i = 0
    except KeyboardInterrupt as e:
        i = 0
    except Exception as e:
        i = 1
    sys.exit(i)

